@@ -10,7 +10,7 @@ use tokio::runtime::Runtime;
 use url::Url;
 
 use crate::backend::{ABackend, Backend, BackendList, BackendType};
-use crate::cache::CacheManager;
+use crate::cache::{CacheManager, CacheManagerBuilder};
 use crate::cli::args::BackendArg;
 use crate::config::{Config, Settings};
 use crate::git::Git;
@@ -121,17 +121,19 @@ impl VfoxBackend {
         let pathname = ba.short.to_kebab_case();
         let plugin_path = dirs::PLUGINS.join(&pathname);
         Self {
-            remote_version_cache: CacheManager::new(
-                ba.cache_path.join("remote_versions-$KEY.msgpack.z"),
+            remote_version_cache: CacheManagerBuilder::new(
+                ba.cache_path.join("remote_versions.msgpack.z"),
             )
             .with_fresh_duration(*env::MISE_FETCH_REMOTE_VERSIONS_CACHE)
             .with_fresh_file(dirs::DATA.to_path_buf())
             .with_fresh_file(plugin_path.to_path_buf())
-            .with_fresh_file(ba.installs_path.to_path_buf()),
-            exec_env_cache: CacheManager::new(ba.cache_path.join("exec_env-$KEY.msgpack.z"))
+            .with_fresh_file(ba.installs_path.to_path_buf())
+            .build(),
+            exec_env_cache: CacheManagerBuilder::new(ba.cache_path.join("exec_env.msgpack.z"))
                 .with_fresh_file(dirs::DATA.to_path_buf())
                 .with_fresh_file(plugin_path.to_path_buf())
-                .with_fresh_file(ba.installs_path.to_path_buf()),
+                .with_fresh_file(ba.installs_path.to_path_buf())
+                .build(),
             repo: OnceLock::new(),
             ba,
             vfox,
